@@ -112,7 +112,7 @@ def report():
     Data Home: {get_data_home()}
     """)
 
-    data_home = pathlib.Path(get_data_home())
+    data_home = pathlib.Path(get_data_home()).expanduser()
     # Number of .list CMTK directories
     n_jefferislab = len([p for p in data_home.rglob(f'*.list') if p.is_dir()])
     # Number of .h5 H5 file
@@ -136,9 +136,9 @@ def report():
     else:
         for path in nat_paths:
             # Number of .list CMTK directories
-            n_cmtk = len([p for p in path.rglob(f'*.list') if p.is_dir()])
+            n_cmtk = len([p for p in path.expanduser().rglob('*.list') if p.is_dir()])
             # Number of .h5 H5 file
-            n_h5 = len([p for p in path.rglob(f'*.h5') if p.is_file()])
+            n_h5 = len([p for p in path.expanduser().rglob('*.h5') if p.is_file()])
             rep += dedent(f"""\
             {path}: {n_cmtk} CMTK | {n_h5} H5 transforms
             """)
@@ -194,6 +194,12 @@ def register_transforms():
                            [transforms.h5reg.H5transform, transforms.cmtk.CMTKtransform]):
             for hit in path.rglob(f'*{ext}'):
                 if hit.is_dir() or hit.is_file():
+                    # These files are inside the CMTK folders and show as
+                    # symlinks in OSX/Linux but as files (?) in Windows
+                    # Hence we need to manually exclude them.
+                    if hit.name in ('orig.list', 'original.list'):
+                        continue
+
                     # Register this transform
                     try:
                         if 'mirror' in hit.name or 'imgflip' in hit.name:
@@ -302,3 +308,13 @@ def register_transforms():
                                            source='FAFB14',
                                            target=None,
                                            transform_type='mirror')
+
+    # Add a simple symmetrization transform for FAFB14
+    fp = os.path.join(data_filepath, 'FAFB14_symmetrize_landmarks_nm.csv')
+    lm = pd.read_csv(fp)
+    tr = transforms.thinplate.TPStransform(lm[['x', 'y', 'z']].values,
+                                           lm[['x_sym', 'y_sym', 'z_sym']].values)
+    transforms.registry.register_transform(transform=tr,
+                                           source='FAFB14',
+                                           target='FAFB14sym',
+                                           transform_type='bridging')
